pub struct RemoveQueryBuilder { /* private fields */ }Expand description
Builder for a remove query request.
Implementations
Sourceimpl RemoveQueryBuilder
impl RemoveQueryBuilder
Sourcepub fn start(self, time: SystemTime) -> Self
pub fn start(self, time: SystemTime) -> Self
Set the start time of the query.
Sourcepub fn start_us(self, time_us: u64) -> Self
pub fn start_us(self, time_us: u64) -> Self
Set the start time of the query as a unix timestamp in microseconds.
Sourcepub fn stop(self, time: SystemTime) -> Self
pub fn stop(self, time: SystemTime) -> Self
Set the end time of the query.
Sourcepub fn stop_us(self, time_us: u64) -> Self
pub fn stop_us(self, time_us: u64) -> Self
Set the end time of the query as a unix timestamp in microseconds.
Sourcepub fn when(self, condition: Value) -> Self
pub fn when(self, condition: Value) -> Self
Set the condition for the query. This will remove all records that match the condition. This is a destructive operation.