pub struct WriteRecordBatchBuilder { /* private fields */ }Expand description
Builder for writing multiple records across entries in a single request.
Implementations
Sourceimpl WriteRecordBatchBuilder
impl WriteRecordBatchBuilder
Sourcepub fn add_record(self, record: Record) -> Self
pub fn add_record(self, record: Record) -> Self
Sourcepub fn append_record(&mut self, record: Record)
pub fn append_record(&mut self, record: Record)
Sourcepub fn add_records(self, records: Vec<Record>) -> Self
pub fn add_records(self, records: Vec<Record>) -> Self
Sourcepub fn append_records(&mut self, records: Vec<Record>)
pub fn append_records(&mut self, records: Vec<Record>)
Sourcepub async fn send(
self,
) -> Result<BTreeMap<(String, u64), ReductError>, ReductError>
pub async fn send( self, ) -> Result<BTreeMap<(String, u64), ReductError>, ReductError>
Sourcepub fn record_count(&self) -> usize
pub fn record_count(&self) -> usize
Get the number of records in the batch.
Sourcepub fn last_access(&self) -> SystemTime
pub fn last_access(&self) -> SystemTime
Get the last time a record was added to the batch.
Can be used for sending the batch after a certain period of time.